package org.foo.paint;

import org.osgi.framework.BundleActivator;
import org.osgi.framework.BundleContext;
import org.osgi.framework.BundleException;


import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;
import javax.swing.JFrame;
import javax.swing.SwingUtilities;
//import org.osgi.framework.*;

/**
 * The activator of the host application bundle. The activator creates the main
 * application <tt>JFrame</tt> and starts tracking <tt>SimpleShape</tt>
 * extensions. All activity is performed on the Swing event thread to avoid
 * synchronization and repainting issues. Closing the application window will
 * result in <tt>Bundle.stop()</tt> being called on the system bundle, which
 * will cause the framework to shutdown and the JVM to exit.
 **/
public class Activator implements BundleActivator, Runnable {
  private BundleContext m_context = null;
  private PaintFrame m_frame = null;
  private ShapeTracker m_shapetracker = null;

  /**
   * Displays the applications window and starts extension tracking; everything
   * is done on the Swing event thread to avoid synchronization and repainting
   * issues.
   * 
   * @param context The context of the bundle.
   **/
  public void start(BundleContext context) {

	System.out.println("PAINT - start");  
	m_context = context;
    if (SwingUtilities.isEventDispatchThread()) {
      run();
    } else {
      try {
        javax.swing.SwingUtilities.invokeAndWait(this);
      } catch (Exception ex) {
        ex.printStackTrace();
      }
    }
  }

  /**
   * Stops extension tracking and disposes of the application window.
   * 
   * @param context The context of the bundle.
   **/
  public void stop(BundleContext context) {
	  System.out.println("PAINT - stop"); 
	  
	  m_shapetracker.close();
    final PaintFrame frame = m_frame;
    javax.swing.SwingUtilities.invokeLater(new Runnable() {
      public void run() {
        frame.setVisible(false);
        frame.dispose();
      }
    });
  }

  /**
   * This method actually performs the creation of the application window. It is
   * intended to be called by the Swing event thread and should not be called
   * directly.
   **/
  public void run() {
    m_frame = new PaintFrame();

    m_frame.setDefaultCloseOperation(JFrame.DO_NOTHING_ON_CLOSE);
    m_frame.addWindowListener(new WindowAdapter() {
      public void windowClosing(WindowEvent evt) {
        try {
          m_context.getBundle(0).stop();
        } catch (BundleException ex) {
          ex.printStackTrace();
        }
      }
    });

    m_frame.setVisible(true);

    m_shapetracker = new ShapeTracker(m_context, m_frame);
    m_shapetracker.open();
  }
}
