
package org.foo.shape;

import java.awt.Graphics2D;
import java.awt.Point;

/**
 * This interface defines the <tt>SimpleShape</tt> extension. This extension is
 * used to draw shapes. It is defined by three manifest properties:
 * <ul>
 * <li>Extension-Name - A <tt>String</tt> name for the shape.</li>
 * <li>Extension-Icon - An <tt>Icon</tt> resource for the shape.</li>
 * <li>Extension-Class - A <tt>Class</tt> that implements the shape.</li>
 * </ul>
 **/
public interface SimpleShape {

  /**
   * A property for the name of the shape.
   **/
  public static final String NAME_PROPERTY = "Extension-Name";

  /**
   * A property for the icon of the shape.
   **/
  public static final String ICON_PROPERTY = "Extension-Icon";

  /**
   * A property for the class of the shape.
   **/
  public static final String CLASS_PROPERTY = "Extension-Class";

  /**
   * Draw this shape at the given position.
   * 
   * @param g2 The graphics object used for painting.
   * @param p The position to paint the shape.
   **/
  public void draw(Graphics2D g2, Point p);
}
